@@ -33,6 +33,8 @@
 
 #include "sidx_config.h"
 
+#include <stddef.h>
+
 IDX_C_START
 
 SIDX_DLL IndexH Index_Create(IndexPropertyH properties);
@@ -41,6 +43,8 @@ SIDX_DLL IndexH Index_CreateWithStream( IndexPropertyH properties,
 										int (*readNext)(int64_t *id, double **pMin, double **pMax, uint32_t *nDimension, const uint8_t **pData, size_t *nDataLength)
 									   );
 
+SIDX_DLL IndexH Index_CreateWithArray(IndexPropertyH properties, uint64_t n, uint32_t dimension, uint64_t i_stri, uint64_t d_i_stri, uint64_t d_j_stri, int64_t *ids, double *mins, double *maxs);
+
 SIDX_DLL void Index_Destroy(IndexH index);
 SIDX_DLL IndexPropertyH Index_GetProperties(IndexH index);
 
@@ -163,6 +167,18 @@ SIDX_DLL RTError Index_Intersects_id(	IndexH index,
 										int64_t** items,
 										uint64_t* nResults);
 
+SIDX_C_DLL RTError Index_Intersects_id_v(IndexH index,
+                                         int64_t n,
+                                         uint32_t d,
+                                         uint64_t idsz,
+                                         uint64_t d_i_stri,
+                                         uint64_t d_j_stri,
+                                         const double* mins,
+                                         const double* maxs,
+                                         int64_t* ids,
+                                         uint64_t* cnts,
+                                         int64_t* nr);
+
 SIDX_C_DLL RTError Index_Contains_id(IndexH index,
                                      double *pdMin,
                                      double *pdMax,
@@ -254,6 +270,20 @@ SIDX_DLL RTError Index_NearestNeighbors_id( IndexH index,
 											int64_t** items,
 											uint64_t* nResults);
 
+SIDX_C_DLL RTError Index_NearestNeighbors_id_v(IndexH index,
+                                               int64_t knn,
+                                               int64_t n,
+                                               uint32_t d,
+                                               uint64_t idsz,
+                                               uint64_t d_i_stri,
+                                               uint64_t d_j_stri,
+                                               const double* mins,
+                                               const double* maxs,
+                                               int64_t* ids,
+                                               uint64_t* cnts,
+                                               double* dists,
+                                               int64_t* nr);
+
 SIDX_DLL RTError Index_Intersects_internal(	IndexH index,
 											double* pdMin,
 											double* pdMax,
